@@ -1,4 +1,5 @@
 from typing import Any
+from warnings import warn
 from copy import deepcopy
 from os import path, makedirs, remove
 
@@ -57,11 +58,12 @@ class BaseLang:
             raise ValueError('"default_dictionary" argument should be a dictionary or a path to file string. Provided value is {0}'
                              .format(default_dictionary))
 
-        if auto_file_creation:
-            if not self.is_file_exist() or force_overwrite_file:
+        if not self.file_exists() or force_overwrite_file:
+            if auto_file_creation:
                 self.create_file()
-
-        self.reload()
+            self.reset_to_defaults
+        else:
+            self.reload()
 
     def __getitem__(self, key):
         return self.__parsed_dict[key]
@@ -278,7 +280,7 @@ class BaseLang:
             ``False`` will be returned.
         :rtype: bool
         """
-        if not self.is_file_exist():
+        if not self.file_exists():
             return False
 
         if safe_mode:
@@ -296,7 +298,7 @@ class BaseLang:
             ``False`` will be returned.
         :rtype: bool
         """
-        if self.is_file_exist():
+        if self.file_exists():
             self.__parsed_dict = self.read_file_as_dict()
             return True
         else:
@@ -326,7 +328,7 @@ class BaseLang:
             False will be returned only if the local file does not exist at the time of deletion.
         :rtype: bool
         """
-        if self.is_file_exist():
+        if self.file_exists():
             remove(self.local_file_path)
             return True
         else:
@@ -335,6 +337,22 @@ class BaseLang:
     def is_file_exist(self) -> bool:
         """Check local file existence
 
+        :return: Does the file exist
+        :rtype: bool
+
+        .. deprecated:: 2.3.0
+           This method will be removed in ``3.0.0`` release.
+           Use ``.file_exists()`` method instead
+        """
+        deprecation_mark(
+            'Method was deprecated in version "2.3.0" and will be '
+            'removed in version "3.0.0". Use ".file_exists()" method instead'
+        )
+        return self.file_exists()
+
+    def file_exists(self) -> bool:
+        """Check local file existence
+
         :return: Does the file exist
         :rtype: bool
         """
@@ -424,3 +442,14 @@ def recursive_dicts_merge(merge_from: dict, merge_to: dict) -> dict:
     __merge(merge_from, result_dict)
 
     return result_dict
+
+
+def deprecation_mark(deprecation_note: str) -> None:
+    """
+    Function used to mark something deprecated in this package
+
+    :param deprecation_note: What and when was deprecated message,
+                             that will be collected by loggers
+    :type deprecation_note: str
+    """
+    warn(deprecation_note, DeprecationWarning)
